@@ -1,11 +1,11 @@
-# Copyrights 1999,2001-2012 by Mark Overmeer.
+# Copyrights 1999,2001-2012 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.00.
 
 package MIME::Types;
 use vars '$VERSION';
-$VERSION = '1.33';
+$VERSION = '1.36';
 
 
 use strict;
@@ -526,13 +526,13 @@ application/vnd.oasis.opendocument.text-master;odm
 application/vnd.oasis.opendocument.text-template;ott
 application/vnd.oasis.opendocument.text-web;oth
 application/vnd.obn
-application/vnd.openxmlformats-officedocument.presentationml.presentation;pptx;binary
-application/vnd.openxmlformats-officedocument.presentationml.slideshow;ppsx;binary
-application/vnd.openxmlformats-officedocument.presentationml.template;potx;binary
-application/vnd.openxmlformats-officedocument.spreadsheetml.sheet;xlsx;binary
-application/vnd.openxmlformats-officedocument.spreadsheetml.template;xltx;binary
-application/vnd.openxmlformats-officedocument.wordprocessingml.document;docx;binary
-application/vnd.openxmlformats-officedocument.wordprocessingml.template;dotx;binary
+application/vnd.openxmlformats-officedocument.presentationml.presentation;pptx;base64
+application/vnd.openxmlformats-officedocument.presentationml.slideshow;ppsx;base64
+application/vnd.openxmlformats-officedocument.presentationml.template;potx;base64
+application/vnd.openxmlformats-officedocument.spreadsheetml.sheet;xlsx;base64
+application/vnd.openxmlformats-officedocument.spreadsheetml.template;xltx;base64
+application/vnd.openxmlformats-officedocument.wordprocessingml.document;docx;base64
+application/vnd.openxmlformats-officedocument.wordprocessingml.template;dotx;base64
 application/vnd.osa.netdeploy
 application/vnd.palm;prc,pdb,pqa,oprc
 application/vnd.paos.xml
@@ -874,6 +874,7 @@ audio/vnd.qcelp
 audio/vnd.rhetorex.32kadpcm
 audio/vnd.sealedmedia.softseal.mpeg;smp3,smp,s1m
 audio/vnd.vmx.cvsd
+audio/webm;;base64
 audio/x-aiff;aif,aifc,aiff;base64
 audio/x-gsm;gsm
 audio/x-midi;mid,midi,kar;base64
@@ -1175,6 +1176,7 @@ video/vnd.sealed.mpeg4;smpg,s14
 video/vnd.sealed.swf;sswf,ssw
 video/vnd.sealedmedia.softseal.mov;smov,smo,s1q
 video/vnd.vivo;viv,vivo
+video/webm;webm;base64
 video/x-fli;fli;base64
 video/x-flv;flv;base64
 video/x-la-asf;lsf,lsx
